"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeMessageToTableMappingTemplate = void 0;
const graphql_transformer_core_1 = require("@aws-amplify/graphql-transformer-core");
const ts_dedent_1 = require("ts-dedent");
const writeMessageToTableMappingTemplate = (fieldName) => {
    const req = createWriteMessageToTableRequestFunction(fieldName);
    const res = createWriteMessageToTableResponseFunction();
    return { req, res };
};
exports.writeMessageToTableMappingTemplate = writeMessageToTableMappingTemplate;
const createWriteMessageToTableRequestFunction = (fieldName) => {
    const requestFunctionString = `
    import { util } from '@aws-appsync/utils'
    import * as ddb from '@aws-appsync/utils/dynamodb'

    export function request(ctx) {
      const args = ctx.stash.transformedArgs ?? ctx.args;
      const defaultValues = ctx.stash.defaultValues ?? {};
      const message = {
          __typename: 'ConversationMessage${fieldName}',
          role: 'user',
          ...args,
          ...defaultValues,
      };
      const id = ctx.stash.defaultValues.id;

      return ddb.put({ key: { id }, item: message });
    }
    `;
    return graphql_transformer_core_1.MappingTemplate.inlineTemplateFromString((0, ts_dedent_1.dedent)(requestFunctionString));
};
const createWriteMessageToTableResponseFunction = () => {
    const responseFunctionString = `
    export function response(ctx) {
      if (ctx.error) {
        util.error(ctx.error.message, ctx.error.type);
      } else {
        return ctx.result;
      }
    }
    `;
    return graphql_transformer_core_1.MappingTemplate.inlineTemplateFromString((0, ts_dedent_1.dedent)(responseFunctionString));
};
//# sourceMappingURL=write-message-to-table-resolver.js.map